@@ -1,6 +1,5 @@
 from .base_dataset import Dataset
 
-
 try:
     from yaml import CSafeLoader as YAMLSafeLoader
 except ImportError:
@@ -12,6 +11,5 @@ class DemoDataset(Dataset):
     def __getitem__(self, idx):
         return self.sample_list[idx]
 
-    @staticmethod
-    def _parse_struct(sample):
+    def _parse_struct(self, sample):
         return sample
