@@ -9,10 +9,9 @@ from .special import (
     PolygonField,
     DateField,
     TimeField,
+    KeypointField,
 )
-from .unstructure import ImageField
-from .registry import STRUCT, CLASSDOMAIN, LABEL
-from .class_domain import ClassDomain, Label
+from .unstructure import ImageField, SegMapField
 
 __all__ = [
     "Struct",
@@ -30,9 +29,6 @@ __all__ = [
     "PolygonField",
     "DateField",
     "TimeField",
-    "STRUCT",
-    "CLASSDOMAIN",
-    "ClassDomain",
-    "LABEL",
-    "Label",
+    "SegMapField",
+    "KeypointField",
 ]
