@@ -1,5 +1,5 @@
 from .field import Field
-from ..geometry import ImageMedia
+from ..geometry import ImageMedia, SegmentationMap
 
 
 class FileReader(object):
@@ -34,3 +34,14 @@ class ImageField(UnstructuredObjectField):
         if isinstance(value, str):
             value = {"$loc": value}
         return ImageMedia(value["$loc"], FileReader(self.file_reader, value))
+
+
+class SegMapField(UnstructuredObjectField):
+    def __init__(self, dom, *args, **kwargs):
+        super(SegMapField, self).__init__(*args, **kwargs)
+        self.dom = dom
+
+    def validate(self, value):
+        if isinstance(value, str):
+            value = {"$loc": value}
+        return SegmentationMap(value['$loc'], FileReader(self.file_reader, value), self.dom)
